class Cogl < Formula
  desc "Low level OpenGL abstraction library developed for Clutter"
  homepage "https://gitlab.gnome.org/GNOME/cogl"
  url "https://download.gnome.org/sources/cogl/1.22/cogl-1.22.8.tar.xz"
  sha256 "a805b2b019184710ff53d0496f9f0ce6dcca420c141a0f4f6fcc02131581d759"
  license all_of: ["MIT", "SGI-B-2.0", "BSD-3-Clause", :public_domain]
  head "https://gitlab.gnome.org/GNOME/cogl.git", branch: "cogl-1.22"

  # https://blogs.gnome.org/clutter/2022/02/16/retiring-clutter/
  deprecate! date: "2022-09-21", because: :deprecated_upstream

  depends_on "gobject-introspection" => :build
  depends_on "pkg-config" => :build
  depends_on "cairo"
  depends_on "gdk-pixbuf"
  depends_on "glib"
  depends_on "pango"

  on_linux do
    depends_on "libxcomposite"
    depends_on "mesa"
  end

  def install
    # Don't dump files in $HOME.
    ENV["GI_SCANNER_DISABLE_CACHE"] = "yes"

    args = %W[
      --disable-dependency-tracking
      --disable-silent-rules
      --prefix=#{prefix}
      --enable-cogl-pango=yes
      --enable-introspection=yes
    ]

    if OS.mac?
      args << "--disable-glx"
      args << "--without-x"
    else
      args << "--enable-xlib-egl-platform=yes"
    end

    system "./configure", *args
    system "make", "install"
  end
  test do
    (testpath/"test.c").write <<~EOS
      #include <cogl/cogl.h>

      int main()
      {
          CoglColor *color = cogl_color_new();
          cogl_color_free(color);
          return 0;
      }
    EOS
    system ENV.cc, "-I#{include}/cogl",
           "-I#{Formula["glib"].opt_include}/glib-2.0",
           "-I#{Formula["glib"].opt_lib}/glib-2.0/include",
           testpath/"test.c", "-o", testpath/"test",
           "-L#{lib}", "-lcogl"
    system "./test"
  end
end
